@@ -968,8 +968,12 @@ class Base(unittest.TestCase):
             driver_path = os.path.join(os.path.dirname(__file__), r'drivers\\windows\\electron\\chromedriver.exe')# TODO chromedriver electron version
             options = ChromeOpt()
             options.add_argument('--log-level=3')
+            options.add_argument(f'--environment="{self.config.environment}"')
+            options.add_argument(f'--url="{self.config.url}"')
+            options.add_argument(f'--program="{self.config.start_program}"')
+            options.add_argument('--quiet')
             options.binary_location = self.config.electron_binary_path
-            self.driver = webdriver.Chrome(chrome_options=options, executable_path=driver_path)
+            self.driver = webdriver.Chrome(options=options, executable_path=driver_path)
 
         if not self.config.browser.lower() == "electron":
             if self.config.headless:
