@@ -88,11 +88,11 @@ class BaseDatabase(Base):
         .. note::  
             Default Database information is in config.json another way is possible put this in the QueryExecute method parameters:
             Parameters:
-                "DBDriver": "",
-                "DBServer": "",
-                "DBName": "",
-                "DBUser": "",
-                "DBPassword": ""
+            "DBDriver": "",
+            "DBServer": "",
+            "DBName": "",
+            "DBUser": "",
+            "DBPassword": ""
 
         .. note::        
             Must be used an ANSI default SQL statement.
@@ -116,12 +116,14 @@ class BaseDatabase(Base):
         :type database_user: str
         :param database_password: Database password
         :type database_password: str
+
         Usage:
+
         >>> # Call the method:
         >>> self.oHelper.QueryExecute("SELECT * FROM SA1T10")
         >>> self.oHelper.QueryExecute("SELECT * FROM SA1T10", database_driver="DRIVER_ODBC_NAME", database_server="SERVER_NAME", database_name="DATABASE_NAME", database_user="sa", database_password="123456")
         >>> # Oracle Example:
-        >>> self.oHelper.QueryExecute("SELECT * FROM SA1T10", database_driver="Oracle in OraClient19Home1", dbq_oracle_server=Host:Port/oracle instance, database_server="SERVER_NAME", database_name="DATABASE_NAME", database_user="sa", database_password="123456")
+        >>> self.oHelper.QueryExecute("SELECT * FROM SA1T10", database_driver="Oracle in OraClient19Home1", dbq_oracle_server="Host:Port/oracle instance", database_server="SERVER_NAME", database_name="DATABASE_NAME", database_user="sa", database_password="123456")
         """
         connection = self.connect_database(query, database_driver, dbq_oracle_server, database_server, database_port, database_name, database_user, database_password)
         
